@@ -1,17 +1,16 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in /LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-
-from __future__ import absolute_import
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
+import pickle
 import unittest
 
-import six.moves as sm
-
 from traits.api import Dict, HasTraits, Int, List
 
 
@@ -21,7 +20,7 @@ class C(HasTraits):
 
     # And we must initialize it to something non-trivial
     def __init__(self):
-        super(C, self).__init__()
+        super().__init__()
         self.a = {1: [2, 3]}
 
 
@@ -29,8 +28,8 @@ class PickleValidatedDictTestCase(unittest.TestCase):
     def test_pickle_validated_dict(self):
 
         # And we must unpickle one
-        x = sm.cPickle.dumps(C())
+        x = pickle.dumps(C())
         try:
-            sm.cPickle.loads(x)
+            pickle.loads(x)
         except AttributeError as e:
             self.fail("Unpickling raised an AttributeError: %s" % e)
